#include <cstdio>
#include <iostream>
#include <sstream>
#include <algorithm>
#include <cassert>
#include <exception>

using namespace std;

const string taskId = "apples";
const int kmax = 1000;
const int amax = 1000;

/*
 * TULong definition
 */
class TULong {
public:
    TULong();
    TULong(size_t rhs);

    TULong & operator *= (size_t rhs);
    TULong & operator += (const TULong & rhs);
    TULong & operator -= (const TULong & rhs);
    bool operator < (const TULong & rhs) const;

    string ToString() const;
    size_t GetLength() const { return Length; }
    size_t operator [] (size_t index) const;

private:
    static const size_t MAX_DIGITS = 100;

    void Init();
    int Diff(const TULong & rhs) const;

    size_t Base;
    size_t Length;
    size_t Digit[MAX_DIGITS];
};

/*
 * TULong implementation
 */

void TULong::Init()
{
    Base = 1000000;
    Length = 0;
    for (size_t i = 0; i < MAX_DIGITS; ++i) {
        Digit[i] = 0;
    }
}

TULong::TULong() {
    Init();
}

TULong::TULong(size_t rhs)
{
    Init();
    while (rhs) {
        Digit[Length++] = rhs % Base;
        rhs /= Base;
    }
}

TULong & TULong::operator *= (size_t rhs)
{
    size_t i = 0;
    for (size_t save = 0; save || i < GetLength(); ++i) {
        if (i == MAX_DIGITS) {
            throw exception();
        }
        Digit[i] = save + Digit[i]*rhs;
        save = Digit[i] / Base;
        Digit[i] -= save*Base;
    }
    if (GetLength() < i) {
        Length = i;
    }

    return *this;
}

TULong & TULong::operator += (const TULong & rhs)
{
    size_t length = GetLength() > rhs.GetLength() ? GetLength() : rhs.GetLength();
    size_t i = 0;
    for (size_t save = 0; save || i < length; ++i) {
        Digit[i] += rhs[i] + save;
        save = Digit[i] / Base;
        Digit[i] -= save*Base;
    }
    if (GetLength() < i) {
        Length = i;
    }
    return *this;
}

TULong & TULong::operator -= (const TULong & rhs)
{
    for (size_t save = 0, i = 0; save || i < rhs.GetLength(); ++i) {
        save += rhs[i];
        if (Digit[i] < save) {
            Digit[i] += Base - save;
            save = 1;
        } else {
            Digit[i] -= save;
            save = 0;
        }
    }
    while (Length && !Digit[Length - 1]) {
        --Length;
    }

    return *this;
}


int TULong::Diff(const TULong & rhs) const
{
    if (GetLength() != rhs.GetLength()) {
        return GetLength() - rhs.GetLength();
    }
    for (size_t i = GetLength(); i > 0; --i) {
        if (Digit[i] != rhs[i]) {
            return Digit[i] - rhs[i];
        }
    }
    return 0; /// they are equal
}

bool TULong::operator < (const TULong & rhs) const
{
    return Diff(rhs) < 0;
}

static string IntToStr(size_t value) {
    static char buf[] = "0123456789";
    sprintf(buf, "%lu", value);
    return string(buf);
}

string TULong::ToString() const {
    if (!GetLength()) {
        return "0";
    }
    string ret = IntToStr(Digit[Length - 1]);
    for (size_t i = Length - 1; i > 0; --i) {
        size_t action = Digit[i - 1];
        while (action*10 < Base) {
            ret += '0';
            action *= 10;
        }
        ret += IntToStr(Digit[i - 1]);
    }
    return ret;
}

size_t TULong::operator [] (size_t index) const {
    if (index >= MAX_DIGITS) {
        throw exception();
    }
    return Digit[index];
}

const TULong operator + (const TULong & lhs, const TULong & rhs)
{
    TULong ret(lhs);
    ret += rhs;
    return ret;
}

const TULong operator - (const TULong & lhs, const TULong & rhs)
{
    TULong ret(lhs);
    ret -= rhs;
    return ret;
}


ostream & operator << (ostream & out, const TULong & value) {
    return (out << value.ToString());
}

typedef TULong TAnswerType;

int main()
{
    if (taskId != "") {
        freopen((taskId + ".in").data(), "rt", stdin);
        freopen((taskId + ".out").data(), "wt", stdout);
    }

    int k;
    int a[kmax];
    
    cin >> k;
    assert(k >= 1 && k <= kmax);
    for (int i = 0; i < k; ++i) {
        cin >> a[i];
        assert(a[i] >= 0 && a[i] <= amax);
    }

    TAnswerType kpower2 = 1;
    TAnswerType middle = 0;
    for (int i = k - 1; i >= 0; --i) {
        middle += a[i];
        middle *= 2;

        kpower2 *= 2;
    }

    TAnswerType best = middle + kpower2 - 1;
    TAnswerType worst = (middle < kpower2) ? 0 : middle - kpower2 + 1;

    cout << worst << endl << best << endl;

    return 0;
}
